// On définit ici le plugin dans une closure, de façon à pouvoir utiliser
// la variable $ de façon sécurisée comme faisant référence à jQuery
// sans risque de confusion avec tout autre plugin
(function($) {

    // Pour respecter le fonctionnement des méthodes et fonctions du framework jQuery,
    // nous allons ici définir :
    //  1. Une fonction dataTable prenant en paramètre une ligne de tableau à traiter
    //  2. Une méthode dataTable, chainable, faisant appel à la fonction dataTable pour chacun
    //     des éléments de la chaine, et retournant tous les éléments de la chaine
    //     (en l'occurence toutes les lignes de tableau)

    // Définition de la fonction dataTable (qui prend en paramètre un élément
    // (ici une ligne de tableau) à traiter
    $.dataTable = function(el) {

        // Sauvegarde du scope et des réréfence à l'élément passé en paramètre
        var base = this;
        base.$el = $(el);
        base.el = el;

        // La méthode init permet d'ajouter à la ligne passée en paramètre, el,
        // toutes les fonctionnalitées décrites dans l'article
        base.init = function() {
            base.$el.find("tbody tr:odd").addClass("odd");
            base.$el.find('tbody tr').mouseover(
                function() {
                    $(this).addClass('hover');
                }).mouseout(
                function() {
                    $(this).removeClass('hover');
                }).click(function() {
                    $(this).toggleClass('selected');
                });
        };

        // Appel de la fonction d'initialisation
        base.init();

        // On retourne l'élément passé en paramètre pour maintenir le chainage
        return base;
    };

    // Définition de la méthode dataTable, qui permet le chainage.
    // Elle retourne tous les éléments (return this.each())
    // qu'elle a elle même récupérée de la chaine, et fait appel à la fonction
    // dataTable pour chacun des élément (chacune des lignes)
    $.fn.dataTable = function() {
        return this.each(function() {
            (new $.dataTable(this));
        });
    };
})(jQuery);
// Fin de la closure